@@ -1,10 +1,11 @@
-/*
-Gwenview: an image viewer
-SPDX-FileCopyrightText: 2009 Aurélien Gâteau <agateau@kde.org>
+/* ============================================================
+*
+* SPDX-FileCopyrightText: 2009 Aurélien Gâteau <agateau@kde.org>
+*
+* SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*
+* ============================================================ */
 
-SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
-
-*/
 #ifndef SPLITTERCOLLAPSER_H
 #define SPLITTERCOLLAPSER_H
 
@@ -28,7 +29,7 @@ class SplitterCollapser : public QToolButton
     Q_OBJECT
 public:
     SplitterCollapser(QSplitter *, QWidget *widget);
-    ~SplitterCollapser();
+    ~SplitterCollapser() override;
 
     QSize sizeHint() const override;
 
